/*******************************************************************************
* 			"Quality Signaling and Demand for Renewable Energy Technology:
                    Evidence from a Randomized Field Experiment"
*   					  	   MASTER DO-FILE							   	   *
********************************************************************************

					PART 0:  User inputs
					PART 1:  Prepare folder paths
					PART 2:  Load necessary packages
					PART 3:  Run selected code

********************************************************************************
	PART 0: USER INPUTS															
*******************************************************************************/
	
	version 18

	set varabbrev on


//	Set user-dependant project paths -------------------------------------------

	global user 	"ENTER/PATH/HERE"	
	sysdir set PLUS "$user/Code/ado"
	
	ieboilstart, v(15.1)  matsize(10000)
	`r(version)'

	
// Select sections to run ------------------------------------------------------

	local  packages			1 // Install user-written commands used in the project
	local  construction		1 // Re-create analysis indicators
	local  mainresults		1 // Re-create analysis outputs



/*******************************************************************************
					PART 1:  Prepare folder paths
*******************************************************************************/

	* Do files
	global do           		"$user/Code"

	* Data sets
	global cleandata 			"$user/Data/01_cleaned"
	global finaldata 			"$user/Data/02_final"
	
	* Outputs
	global output 				"$user/Output"

/*******************************************************************************
					PART 2:  Load necessary packages
*******************************************************************************/
{

	* Install packages
	if `packages' {
		foreach package in ietoolkit iefieldkit estpost outreg2 distplot ///
		mhtexp ritest {
			capture which `package'
            if _rc == 111	ssc install `package'
		}
	}
}

********************************************************************************
*					   PART 3: Define globals for analysis					   *
********************************************************************************

global sociodemographics_1 	age female educ1 educ2 educ3 educ4 educ5 roof_bin ///
							hhsize
global sociodemographics_2 	age female i.education_cat roof_bin hhsize  

global attitudes 		    risk_zero trust_wb_zero trust_total_zero ///
							trust_ngo_zero

global lampexperience	    solarlamp_experience_bin solarlamp_penetration  

********************************************************************************
*					   PART 3: Run selected code     						   *
********************************************************************************

	if `construction' 	do "${do}/var_construction/DataPrep_QualitySignalingSenegal.do"
	if `mainresults' 	do "${do}/analysis/MASTER_paper_results.do"
  
/*******************************************************************************
	Congratulations, you've made it to the end of the do files!
******************************************************************************/

