/*******************************************************************************
* 			Quality Signaling and Demand for Renewable Energy Technology:
*                   Evidence from a Randomized Field Experiment"	           *
********************************************************************************
	REQUIRES: ${finaldata}/QualitySignaling_Senegal_PrepData.dta		   	   *
	CREATES:  Output/appendix/tables/table_d12_log.log
				
	WRITEN BY:  Ann-Kristin Reitmann 
	
*******************************************************************************/
	
	//0. Open log file
	log using "$user/Output/appendix/tables/table_d12_log.log", replace
	
	//1. Open Final household cleaned dataset with new variables
	use "$finaldata/QualitySignaling_Senegal_PrepData.dta", clear

**
**Table D12: Table 4 with randomization inference p-values (only for Columns ((3) – (6))
**

/*note 1: no regression output available for command ritest, logfiles are reported instead*/
/*note 2: seed necessary to generate replicable randomization inference p-values*/

*reg ln_wtp_hq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin if ///
						treatment_cat_v2!=3, robust
*outreg2 using 	"$output/appendix/tables/table_d12a.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label replace
*reg ln_wtp_hq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						$sociodemographics_2 $attitudes solarlamp_penetration ///
						lq_first if treatment_cat_v2!=3, robust
*outreg2 using 	"$output/appendix/tables/table_d12a.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes solarlamp_penetration lq_first)
reg ln_wtp_hq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12a.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label replace
reg ln_wtp_hq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12a.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes solarlamp_penetration lq_first)
reg ln_wtp_hq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12a.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append
reg ln_wtp_hq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12a.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes solarlamp_penetration lq_first)

ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_s1_trim2 i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
	& treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_s1_trim2 i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
	solarlamp_penetration lq_first if solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_s1_trim2 i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
	& treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_s1_trim2 i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
	solarlamp_penetration lq_first if solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust

*reg ln_wtp_lq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin if ///
						treatment_cat_v2!=3, robust
*outreg2 using 	"$output/appendix/tables/table_d12b.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label replace
*reg ln_wtp_lq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						$sociodemographics_2 $attitudes solarlamp_penetration ///
						lq_first if treatment_cat_v2!=3, robust
*outreg2 using 	"$output/appendix/tables/table_d12b.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_lq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12b.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label replace
reg ln_wtp_lq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12b.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_lq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12b.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append
reg ln_wtp_lq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12b.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes solarlamp_penetration lq_first)

ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_lq_s1_trim2 i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
	& treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_lq_s1_trim2 i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
	solarlamp_penetration lq_first if solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_lq_s1_trim2 i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
	& treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_lq_s1_trim2 i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
	solarlamp_penetration lq_first if solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust

*reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2##i.solarlamp_experience_bin ///
							if treatment_cat_v2!=3, robust
*outreg2 using 	"$output/appendix/tables/table_d12c.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label replace
*reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2##i.solarlamp_experience_bin ///
							$sociodemographics_2 $attitudes solarlamp_penetration ///
							lq_first if treatment_cat_v2!=3, robust
*outreg2 using 	"$output/appendix/tables/table_d12c.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12c.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label replace
reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12c.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12c.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append
reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d12c.xls", stats (coef pval) bdec(2) pdec(3) rdec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 if ///
	solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 $sociodemographics_2 ///
	$attitudes solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
	& treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
	& treatment_cat_v2!=3, robust
ritest treatment_cat_v2 _b[2.treatment_cat_v2], reps(2000) seed(844126): ///
	reg ln_wtp_hq_lq_diff_trim2 i.treatment_cat_v2 $sociodemographics_2 ///
	$attitudes solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
	& treatment_cat_v2!=3, robust

	//3. Close log file
	log close
