/*******************************************************************************
* 			Quality Signaling and Demand for Renewable Energy Technology:
*                   Evidence from a Randomized Field Experiment"	           *
********************************************************************************
	REQUIRES: ${finaldata}/QualitySignaling_Senegal_PrepData.dta		   	   *
	CREATES:  $output/appendix/tables/table_d3_a.xls
			  $output/appendix/tables/table_d3_b.xls
			  $output/appendix/tables/table_d3_c.xls
				
	WRITEN BY:  Ann-Kristin Reitmann 
	
********************************************************************************
    PART 1: Prepare data
*******************************************************************************/
	
	//0. Open Final household cleaned dataset with new variables
	use "$finaldata/QualitySignaling_Senegal_PrepData.dta", clear
**
**Table D3: Table 4 with WTP in levels
**

/*regression output*/

reg wtp_hq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_a.xls", stats (coef se) ///
				dec(2) label replace
reg wtp_hq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						$sociodemographics_2 $attitudes solarlamp_penetration ///
						lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg wtp_hq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_a.xls", stats (coef se) ///
				dec(2) label append
reg wtp_hq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if ///
						solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg wtp_hq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_a.xls", stats (coef se) ///
				dec(2) label append
reg wtp_hq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if ///
						solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg wtp_lq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_b.xls", stats (coef se) ///
				dec(2) label replace
reg wtp_lq_s1_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						$sociodemographics_2 $attitudes solarlamp_penetration ///
						lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg wtp_lq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_b.xls", stats (coef se) ///
				dec(2) label append
reg wtp_lq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if ///
						solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg wtp_lq_s1_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_b.xls", stats (coef se) ///
				dec(2) label append
reg wtp_lq_s1_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if ///
						solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg wtp_hq_lq_diff_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
							if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_c.xls", stats (coef se) ///
				dec(2) label replace
reg wtp_hq_lq_diff_trim2 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
							$sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg wtp_hq_lq_diff_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_c.xls", stats (coef se) ///
				dec(2) label append
reg wtp_hq_lq_diff_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if ///
							solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg wtp_hq_lq_diff_trim2 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_c.xls", stats (coef se) ///
				dec(2) label append
reg wtp_hq_lq_diff_trim2 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if ///
							solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d3_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
