/*******************************************************************************
* 			Quality Signaling and Demand for Renewable Energy Technology:
*                   Evidence from a Randomized Field Experiment"	           *
********************************************************************************
	REQUIRES: ${finaldata}/QualitySignaling_Senegal_PrepData.dta		   	   *
	CREATES:  ${output}/appendix/tables/table_d6_a.xls
	          ${output}/appendix/tables/table_d6_b.xls
	          ${output}/appendix/tables/table_d6_c.xls
				
	WRITEN BY:  Ann-Kristin Reitmann 
	
********************************************************************************
    PART 1: Prepare data
*******************************************************************************/
	
	//0. Open Final household cleaned dataset with new variables
	use "$finaldata/QualitySignaling_Senegal_PrepData.dta", clear

**
**Table D6: Table 4 without winsorization and winsorized at the five lower and upper percentiles
**

/*regression output*/

reg ln_wtp_hq_s1 i.treatment_cat_v2##i.solarlamp_experience_bin if ///
treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label replace
reg ln_wtp_hq_s1 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
					$sociodemographics_2 $attitudes solarlamp_penetration ///
					lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_s1 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_s1 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
solarlamp_penetration lq_first if solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_s1 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_s1 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
solarlamp_penetration lq_first if solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg ln_wtp_hq_s1_trim5 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_s1_trim5 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						$sociodemographics_2 $attitudes solarlamp_penetration ///
						lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_s1_trim5 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_s1_trim5 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_s1_trim5 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_s1_trim5 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_a.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg ln_wtp_lq_s1 	i.treatment_cat_v2##i.solarlamp_experience_bin if ///
					treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label replace
reg ln_wtp_lq_s1 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
					$sociodemographics_2 $attitudes solarlamp_penetration ///
					lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_lq_s1 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
					& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_lq_s1 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
					solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
					& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_lq_s1 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
					& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_lq_s1 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
					solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
					& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg ln_wtp_lq_s1_trim5 	i.treatment_cat_v2##i.solarlamp_experience_bin if ///
						treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_lq_s1_trim5 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						$sociodemographics_2 $attitudes solarlamp_penetration ///
						lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_lq_s1_trim5 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_lq_s1_trim5 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_lq_s1_trim5 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_lq_s1_trim5 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_b.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg ln_wtp_hq_lq_diff 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label replace
reg ln_wtp_hq_lq_diff 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
						$sociodemographics_2 $attitudes solarlamp_penetration ///
						lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_lq_diff 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_lq_diff 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_lq_diff 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_lq_diff 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
						solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
						& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg ln_wtp_hq_lq_diff_trim5 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
								if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_lq_diff_trim5 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
								$sociodemographics_2 $attitudes solarlamp_penetration ///
								lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_lq_diff_trim5 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
								& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_lq_diff_trim5 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
								solarlamp_penetration lq_first if solarlamp_experience_bin==0 ///
								& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg ln_wtp_hq_lq_diff_trim5 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
								& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append
reg ln_wtp_hq_lq_diff_trim5 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
								solarlamp_penetration lq_first if solarlamp_experience_bin==1 ///
								& treatment_cat_v2!=3, robust
outreg2 using 	"$output/appendix/tables/table_d6_c.xls", stats (coef se) ///
				dec(2) label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
