/*******************************************************************************
* 			Quality Signaling and Demand for Renewable Energy Technology:
*                   Evidence from a Randomized Field Experiment"	           *
********************************************************************************
	REQUIRES: ${finaldata}/QualitySignaling_Senegal_PrepData.dta		   	   *
	CREATES:  ${output}/paper/graphs/figure1.png	
				
	WRITEN BY:  Ann-Kristin Reitmann 
	
********************************************************************************
    PART 1: Prepare data
*******************************************************************************/

	//0. Open Final household cleaned dataset with new variables
	use "$finaldata/QualitySignaling_Senegal_PrepData.dta", clear
	
**FIGURE 1: Treatment effect on WTP for high-quality solar lamp
**

/*mean WTP for each group*/

sum wtp_hq_s1_trim2 if treatment_cat==1 //mean = 2,355
sum wtp_hq_s1_trim2 if treatment_cat==2 //mean = 2,715
sum wtp_hq_s1_trim2 if treatment_cat==3 //mean = 2,679
sum wtp_hq_s1_trim2 if treatment_cat==4 //mean = 2,412

/*graph*/

distplot wtp_hq_s1_trim2, over(treatment_cat)  reverse ///
					graphregion(color(white)) bgcolor(white) ///
					lcolor(navy maroon forest_green dkorange) ///
					legend(label(1 "Control (C)") ///
					label(2 "Lighting Global certification (LGC)") ///
					label(3 "2-year warranty (2YW)") ///
					label(4 "Money-back guarantee (MBG)") position(6) ring(1) col(2) size(medium)  ///
					region(fcolor(white) lcolor(black))) ///
					xlabel(0(1000)10000, format(%9.0fc)) xtitle("Price (in XOF)") ///
					ylabel(,format(%03.1f)) ytitle("Uptake (proportion of sample)") ///
					xline(2355, lpattern(dash) lcolor(navy)) ///
					text(0.95 3000 "mean WTP C (2,355)", ///
					size(small) color(navy) placement(ne)) ///
					xline(2715, lpattern(dash) lcolor(maroon)) ///
					text(0.9 3000 "mean WTP LGC (2,715)", ///
					size(small) color(maroon) placement(ne)) ///
					xline(2679, lpattern(dash) lcolor(forest_green)) ///
					text(0.85 3000 "mean WTP 2YW (2,679)", ///
					size(small) color(forest_green) placement(ne)) ///
					xline(2412, lpattern(dash) lcolor(dkorange)) ///
					text(0.8 3000 "mean WTP MBG (2,412)", ///
					size(small) color(dkorange) placement(ne)) 
					
		
graph export "$output/paper/graphs/figure1.png", as(png) replace

/*two-sample Kolmogorov-Smirnov tests*/

ksmirnov wtp_hq_s1_trim2 if treatment_cat!=3 & treatment_cat!=4, by(treatment_bin)
ksmirnov wtp_hq_s1_trim2 if treatment_cat!=2 & treatment_cat!=4, by(treatment_bin)
ksmirnov wtp_hq_s1_trim2 if treatment_cat!=2 & treatment_cat!=3, by(treatment_bin)
