/*******************************************************************************
* 			Quality Signaling and Demand for Renewable Energy Technology:
*                   Evidence from a Randomized Field Experiment"	           *
********************************************************************************
	REQUIRES: ${finaldata}/QualitySignaling_Senegal_PrepData.dta		   	   *
	CREATES:  ${output}/paper/graphs/figure2.png	
				
	WRITEN BY:  Ann-Kristin Reitmann 
	
********************************************************************************
    PART 1: Prepare data
*******************************************************************************/

	//0. Open Final household cleaned dataset with new variables
	use "$finaldata/QualitySignaling_Senegal_PrepData.dta", clear

**
**FIGURE 2: Demand curves for low-quality and high-quality solar lamps
**

/*mean WTP for each lamp*/

sum wtp_lq_s1_trim2 wtp_hq_s1_trim2 if treatment_cat_v2==2 & ///
solarlamp_experience_bin==1 //means: 2183.55; 2688.095

/*graph*/

distplot wtp_lq_s1_trim2 wtp_hq_s1_trim2 if treatment_cat_v2==2 & ///
solarlamp_experience_bin==1, reverse ///
					graphregion(color(white)) bgcolor(white) lcolor(navy green) ///
					legend(label(1 "LQ solar lamp") label(2 "HQ solar lamp") position(6) ring(1) col(2)  ///
					region(fcolor(white) lcolor(black))) ///
					xlabel(0(1000)10000, format(%9.0fc)) xtitle("Willingness-to-pay (in XOF)") ///
					ylabel(,format(%03.1f)) ytitle("Uptake (proportion of sample)") ///
					xline(2184, lpattern(dash) lcolor(navy)) ///
					text(1 2184 "mean WTP (2,184)", ///
					size(small) color(navy) placement(sw) orientation(vertical)) ///
					xline(2688, lpattern(dash) lcolor(green)) ///
					text(1 2688 "mean WTP (2,688)", ///
					size(small) color(green) placement(sw) orientation(vertical))
graph export "$output/paper/graphs/figure2.png", as(png) replace

*-------------------------------------------------------------------------------
