/*******************************************************************************
* 			Quality Signaling and Demand for Renewable Energy Technology:
*                   Evidence from a Randomized Field Experiment"	           *
********************************************************************************
	REQUIRES: ${finaldata}/QualitySignaling_Senegal_PrepData.dta		   	   *
	CREATES:  ${output}/paper/tables/table1_descriptives.xls
			  ${output}/paper/tables/table1_ttest.xls
			  ${output}/paper/tables/table1_ftest.xls
				
	WRITEN BY:  Ann-Kristin Reitmann 
	
********************************************************************************
    PART 1: Prepare data
*******************************************************************************/
	
	//0. Open Final household cleaned dataset with new variables
	use "$finaldata/QualitySignaling_Senegal_PrepData.dta", clear
	
**
**TABLE 1: Balance test between control and treatment groups
**

/*mean and standard deviations for variables, by treatment and control group*/

estpost tabstat $sociodemographics_1 income_avilable_monthly $attitudes ///
				$lampexperience, by(treatment_bin) columns(statistics) ///
				stats(count mean sd) 
estout . using "$output/paper/tables/table1_descriptives.xls", replace ///
				cell((count mean(fmt(2)) sd(fmt(2)))) label unstack note(C_T)

/*t-test results*/

estpost ttest 	$sociodemographics_1 income_avilable_monthly $attitudes ///
				$lampexperience, by(treatment_bin)
estout . using "$output/paper/tables/table1_ttest.xls", replace ///
				cell((b(fmt(2)) p(fmt(3)) N_1 mu_1(fmt(2)) N_2 mu_2(fmt(2)))) ///
				label unstack note(C vs. T) 

/*joint F-test results*/

reg treatment_bin 	$sociodemographics_2 income_avilable_monthly $attitudes ///
					$lampexperience
outreg2 using 	"$output/paper/tables/table1_ftest.xls", replace stats (coef se) ///
				addstat(F-test, e(F), Prob > F, e(p)) dec(2)  label

/*share of households being able to afford high-quality lamp*/

tab income_mp_8500

/* HH able to |
  afford HQ |
  lamp (=1) |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |        371       38.65       38.65
          1 |        589       61.35      100.00
------------+-----------------------------------
      Total |        960      100.00
*/
