/*******************************************************************************
* 			Quality Signaling and Demand for Renewable Energy Technology:
*                   Evidence from a Randomized Field Experiment"	           *
********************************************************************************
	REQUIRES: ${finaldata}/QualitySignaling_Senegal_PrepData.dta		   	   *
	CREATES:  ${output}/paper/tables/table5_a.xls
	          ${output}/paper/tables/table5_b.xls	
			  ${output}/paper/tables/table5_c.xls
			  
	WRITEN BY:  Ann-Kristin Reitmann 
	
********************************************************************************
    PART 1: Prepare data
*******************************************************************************/
	
	//0. Open Final household cleaned dataset with new variables
	use "$finaldata/QualitySignaling_Senegal_PrepData.dta", clear

**
**TABLE 5: Treatment effects on quality perception, by level of experience
**

/*regression output*/

reg hq_expect_quality_bin 	i.treatment_cat_v2##i.solarlamp_experience_bin if ///
							treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_a.xls", stats (coef se) dec(2) ///
				label replace
reg hq_expect_quality_bin 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
							$sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_a.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg hq_expect_quality_bin 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_a.xls", stats (coef se) dec(2) ///
				label append
reg hq_expect_quality_bin 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if ///
							solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_a.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg hq_expect_quality_bin 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_a.xls", stats (coef se) dec(2) ///
				label append
reg hq_expect_quality_bin 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if ///
							solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_a.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg lq_expect_quality_bin 	i.treatment_cat_v2##i.solarlamp_experience_bin if ///
							treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_b.xls", stats (coef se) dec(2) ///
				label replace
reg lq_expect_quality_bin 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
							$sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_b.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg lq_expect_quality_bin 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_b.xls", stats (coef se) dec(2) ///
				label append
reg lq_expect_quality_bin 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if ///
							solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_b.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg lq_expect_quality_bin 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
							& treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_b.xls", stats (coef se) dec(2) ///
				label append
reg lq_expect_quality_bin 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
							solarlamp_penetration lq_first if ///
							solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_b.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)

reg diff_expect_quality_bin 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
								if treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_c.xls", stats (coef se) dec(2) ///
				label replace
reg diff_expect_quality_bin 	i.treatment_cat_v2##i.solarlamp_experience_bin ///
								$sociodemographics_2 $attitudes ///
								solarlamp_penetration lq_first if treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_c.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg diff_expect_quality_bin 	i.treatment_cat_v2 if solarlamp_experience_bin==0 ///
								& treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_c.xls", stats (coef se) dec(2) ///
				label append
reg diff_expect_quality_bin 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
								solarlamp_penetration lq_first if ///
								solarlamp_experience_bin==0 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_c.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
reg diff_expect_quality_bin 	i.treatment_cat_v2 if solarlamp_experience_bin==1 ///
								& treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_c.xls", stats (coef se) dec(2) ///
				label append
reg diff_expect_quality_bin 	i.treatment_cat_v2 $sociodemographics_2 $attitudes ///
								solarlamp_penetration lq_first if ///
								solarlamp_experience_bin==1 & treatment_cat_v2!=3, robust
outreg2 using 	"$output/paper/tables/table5_c.xls", stats (coef se) dec(2) ///
				label append drop($sociodemographics_2 $attitudes ///
				solarlamp_penetration lq_first)
