*-------------------------------------------------------------------------------
**Data Prep Do-File

/*******************************************************************************
* 			"Quality Signaling and Demand for Renewable Energy Technology:
*                     Evidence from a Randomized Field Experiment"		       *
********************************************************************************
	REQUIRES:	$data\QualitySignaling_Senegal_CleanData.dta
	CREATES:	$data\QualitySignaling_Senegal_PrepData.dta
				
	WRITEN BY:  Ann-Kristin Reitmann
	
*******************************************************************************/

/*fetch cleaned data*/

use "$cleandata/QualitySignaling_Senegal_CleanData.dta", clear

*-------------------------------------------------------------------------------

/*Household ID*/

label var hhid "Household ID"

/*Village code*/

label var village_code "Village (code)"

/*age*/

label var age "Age (years)"

/*gender*/

gen female=0 if gender==1
replace female=1 if gender==2
label var female "Female"

/*education*/

*categorical variable
gen education_cat=.
replace education_cat=1 if education==0
replace education_cat=2 if (education>=1 & education<=6) | education==99
replace education_cat=3 if (education>=7 & education<=13) 
replace education_cat=4 if (education>=14 & education<=17) 
replace education_cat=5 if (education==18) 
label var education_cat "Education (category)"
label def education_cat 1 "No education" 2 "Primary school" 3 "Secondary school" ///
						4 "Higher education" 5 "Other: Koranic school/Daara"
label val education_cat education_cat
tab education_cat, gen(educ)

*binary variables
label var educ1 "No education"
label var educ2 "Primary school"
label var educ3 "Secondary school"
label var educ4 "Higher education"
label var educ5 "Other: Koranic school/Daara"

/*wealth*/

gen roof_bin=.
replace roof_bin=0 if roof==4 | roof==5
replace roof_bin=1 if roof==1 | roof==2 | roof==3
label def roof_bin 0 "Rudimentary" 1 "Finished roof"
label val roof_bin roof_bin
label var roof_bin "Finished roof"

/*income*/

gen farm_zero=farm 
replace  farm_zero=0 if farm==.d | farm==.r //including missings as 0
gen nonfarm_zero=nonfarm
replace  nonfarm_zero=0 if nonfarm==.d | nonfarm==.r //including missings as 0
gen remittances_zero=remittances
replace  remittances_zero=0 if remittances==.d | remittances==.r //including missings as 0
gen benefits_zero=benefits
replace  benefits_zero=0 if benefits==.d | benefits==.r //including missings as 0
gen wage_zero=wage 
replace  wage_zero=0 if wage==.d | wage==.r //including missings as 0
gen renting_zero=renting
replace  renting_zero=0 if renting==.d | renting==.r //including missings as 0
 
gen income_avilable_monthly=0
replace income_avilable_monthly=income_avilable_monthly + farm_zero + ///
		nonfarm_zero + remittances_zero + benefits_zero + wage_zero + renting_zero
label var income_avilable_monthly "Monthly available income (XOF)"

/*share of households being able to afford high-quality lamp*/

gen income_mp_8500=0
replace income_mp_8500=1 if income_avilable_monthly>=8500
label var income_mp_8500 "HH able to afford HQ lamp"

/*household size*/

label var hhsize "Household size (members)"

/*risk attitudes*/

gen risk_zero=risk
replace risk_zero=0 if risk==.d | risk==.r 
label var risk_zero "Willingness to take risks (scale 0-10)" //including missings as 0

/*trust variables*/

*trust in World Bank
gen trust_wb=.
replace trust_wb=0 if wbinfo==5 | wbinfo==4 | wbinfo==3
replace trust_wb=1 if wbinfo==2 | wbinfo==1
label def trust_new 0 "(Strongly) Disagree/Neither" 1 "(Strongly) Agree"
label val trust_wb trust_new
label var trust_wb "Trust in World Bank"

gen trust_wb_zero=trust_wb
replace trust_wb_zero=0 if wbinfo==.d | wbinfo==.r 
label val trust_wb_zero trust_new
label var trust_wb_zero "Trust in World Bank" //including missings as 0

*trust in Total
gen trust_total=.
replace trust_total=0 if totalinfo==5 | totalinfo==4 | totalinfo==3
replace trust_total=1 if totalinfo==2 | totalinfo==1
label val trust_total trust_new
label var trust_total "Trust in Total"

gen trust_total_zero=trust_total
replace trust_total_zero=0 if totalinfo==.d | totalinfo==.r 
label val trust_total_zero trust_new
label var trust_total_zero "Trust in Total" //including missings as 0

*trust in NGOs
gen trust_ngo=.
replace trust_ngo=0 if govinfo==5 | govinfo==4 | govinfo==3
replace trust_ngo=1 if govinfo==2 | govinfo==1
label val trust_ngo trust_new
label var trust_ngo "Trust in NGOs"

gen trust_ngo_zero=trust_ngo
replace trust_ngo_zero=0 if govinfo==.d | govinfo==.r 
label val trust_ngo_zero trust_new
label var trust_ngo_zero "Trust in NGOs" //including missings as 0

/*solar lamp experience*/

*binary variables
gen solarlamp_experience_bin=.
replace solarlamp_experience_bin=1 if solarkit==1
replace solarlamp_experience_bin=0 if solarkit==0
label def experience_bin 0 "No experience" 1 "Solar lamp experience"
label val solarlamp_experience_bin experience_bin
label var solarlamp_experience_bin "Solar lamp experience"

*for mht (mhtexp command, where control group needs to have value of 0)
gen solarlamp_experience_bin_mht=1 if solarlamp_experience_bin==0
replace solarlamp_experience_bin_mht=2 if solarlamp_experience_bin==1

/*village solar lamp penetration*/
sort village_code hhid

by village_code, sort: egen solarlamp_penetration = mean(solarlamp_experience_bin)
label var solarlamp_penetration "Village-level solar lamp penetration rate"

/*treatment*/

*categorical variables
gen treatment_cat=.
replace treatment_cat=1 if treatment=="Control"
replace treatment_cat=2 if treatment=="Lab information"
replace treatment_cat=3 if treatment=="2-yr warranty"
replace treatment_cat=4 if treatment=="Money-back guarantee"
label var treatment_cat "Treatment category"
label def treatment 1 "Control" 2 "LG certification" 3 "2-year warranty" ///
					4 "Money-back guarantee"
label val treatment_cat treatment

*for mht (mhtexp command, where control group needs to have value of 0)
gen treatment_cat_mht=0 if treatment_cat==1
replace treatment_cat_mht=1 if treatment_cat==2
replace treatment_cat_mht=2 if treatment_cat==3
replace treatment_cat_mht=3 if treatment_cat==4

*binary variables
gen treatment_bin=.
replace treatment_bin=1 if treatment_cat==2 | treatment_cat==3 | treatment_cat==4
replace treatment_bin=0 if treatment_cat==1
label def treatment_bin 0 "Control (C)" 1 "Treatment (T)"
label val treatment_bin treatment_bin
label var treatment_bin "Treatment (T)"

gen C_T1=.
replace C_T1=0 if treatment_cat==1
replace C_T1=1 if treatment_cat==2
label var C_T1 "C vs. LGC"

gen C_T2=.
replace C_T2=0 if treatment_cat==1
replace C_T2=1 if treatment_cat==3
label var C_T2 "C vs. 2YW"

gen C_T3=.
replace C_T3=0 if treatment_cat==1
replace C_T3=1 if treatment_cat==4
label var C_T3 "C vs. MBG"

gen T1_T2=.
replace T1_T2=0 if treatment_cat==2
replace T1_T2=1 if treatment_cat==3
label var T1_T2 "LGC vs. 2YW"

gen T1_T3=.
replace T1_T3=0 if treatment_cat==2
replace T1_T3=1 if treatment_cat==4
label var T1_T3 "LGS vs. MBG"

gen T2_T3=.
replace T2_T3=0 if treatment_cat==3
replace T2_T3=1 if treatment_cat==4
label var T2_T3 "2YW vs. MBG"

*cluster LGC and 2YW together as 'durability signaling'
gen treatment_cat_v2=.
replace treatment_cat_v2=1 if treatment_cat==1
replace treatment_cat_v2=2 if treatment_cat==2 | treatment_cat==3
replace treatment_cat_v2=3 if treatment_cat==4
label var treatment_cat_v2 "Treatment category"
label def treatment_v2 	1 "Control (C)" 2 "Durability signaling (LGC, 2YW)" ///
						3 "Utility signaling (MBG)"
label val treatment_cat_v2 treatment_v2

*for mht (mhtexp command, where control group needs to have value of 0)
gen treatment_cat_v2_mht=0 if treatment_cat_v2==1
replace treatment_cat_v2_mht=1 if treatment_cat_v2==2

/*BDM procedure*/

*lamp presentation order 
gen lq_first=.
replace lq_first=1 if lamporder==2
replace lq_first=0 if lamporder==1
label var lq_first "LQ lamp presented first"

*successful bid
gen received_lamp=.
replace received_lamp=0 if outcome=="No-win"
replace received_lamp=1 if outcome=="Win"
label var received_lamp "HH received/won lamp"

*payment refusal despite stated price <= drawn price
gen refused_payment=pay_yn
label var refused_payment "Refused to pay drawn price"

/*willingness-to-pay*/

*absolute WTP for high-quality (HQ) and low-quality (LQ) lamps
rename wtp_hq_all wtp_hq_s1
label var wtp_hq_s1 "WTP for high-quality solar lamp (XOF)"

gen wtp_lq_s1=.
replace wtp_lq_s1=wtp_lq if wtp_lq_rev==.
replace wtp_lq_s1=wtp_lq_rev if wtp_lq==.
label var wtp_lq_s1 "WTP for low-quality solar lamp (XOF)"

*winsoring due to outliers
winsor2 wtp_hq_s1, cuts(2 98)
rename wtp_hq_s1_w wtp_hq_s1_trim2
label var wtp_hq_s1_trim2 "WTP for high-quality solar lamp (XOF)"

winsor2 wtp_lq_s1, cuts(2 98)
rename wtp_lq_s1_w wtp_lq_s1_trim2
label var wtp_lq_s1_trim2 "WTP for low-quality solar lamp (XOF)"

winsor2 wtp_hq_s1, cuts(5 95)
rename wtp_hq_s1_w wtp_hq_s1_trim5
label var wtp_hq_s1_trim5 "WTP for high-quality solar lamp (XOF)"

winsor2 wtp_lq_s1, cuts(5 95)
rename wtp_lq_s1_w wtp_lq_s1_trim5
label var wtp_lq_s1_trim5 "WTP for low-quality solar lamp (XOF)"

*log transformation
foreach var in 	wtp_lq_s1 wtp_hq_s1 wtp_lq_s1_trim2 wtp_hq_s1_trim2 ///
				wtp_lq_s1_trim5 wtp_hq_s1_trim5 {
	gen ln_`var'=ln(`var') if  `var'!=0
	replace ln_`var'=0 if `var'==0
	}
	
label var ln_wtp_hq_s1_trim2 "Log WTP for high-quality solar lamp"
label var ln_wtp_lq_s1_trim2 "Log WTP for low-quality solar lamp"
label var ln_wtp_hq_s1_trim5 "Log WTP for high-quality solar lamp"
label var ln_wtp_lq_s1_trim5 "Log WTP for low-quality solar lamp"

*difference in WTP for HQ and LQ lamp
gen wtp_hq_lq_diff_trim2 = wtp_hq_s1_trim2 - wtp_lq_s1_trim2 
label var wtp_hq_lq_diff_trim2 "Difference in WTP (XOF): high-quality minus low-quality solar lamp"

gen ln_wtp_hq_lq_diff = ln_wtp_hq_s1 - ln_wtp_lq_s1
label var ln_wtp_hq_lq_diff "Difference in log WTP: high-quality minus low-quality solar lamp"

gen ln_wtp_hq_lq_diff_trim2 = ln_wtp_hq_s1_trim2 - ln_wtp_lq_s1_trim2
label var ln_wtp_hq_lq_diff_trim2 "Difference in log WTP: high-quality minus low-quality solar lamp"

gen ln_wtp_hq_lq_diff_trim5 = ln_wtp_hq_s1_trim5 - ln_wtp_lq_s1_trim5
label var ln_wtp_hq_lq_diff_trim5 "Difference in log WTP: high-quality minus low-quality solar lamp"

/*quality*/

*categorical variables
gen hq_expected_quality=.
replace hq_expected_quality=expquality_hq if expquality_hq_rev==.
replace hq_expected_quality=expquality_hq_rev if expquality_hq==.
replace hq_expected_quality=9999 if hq_expected_quality==.r |  hq_expected_quality==.d
label var hq_expected_quality "Expected quality of high-quality solar lamp"
label def quality_new 1 "Very poor" 2 "Poor" 3 "Acceptable" 4 "Good" 5 "Excellent" 
label val hq_expected_quality quality_new

gen lq_expected_quality=.
replace lq_expected_quality=expquality_lq if expquality_lq_rev==.
replace lq_expected_quality=expquality_lq_rev if expquality_lq==.
replace lq_expected_quality=9999 if lq_expected_quality==.r |  lq_expected_quality==.d
label var lq_expected_quality "Expected quality of low-quality solar lamp"  
label val lq_expected_quality quality_new

*binary variables
gen hq_expect_quality_bin=.
replace hq_expect_quality_bin=1 if hq_expected_quality==4 | hq_expected_quality==5 
replace hq_expect_quality_bin=0 if hq_expected_quality>=1 & hq_expected_quality<=3
label def quality_new2 0 "(Very) Poor / Acceptable" 1 "Good / Excellent" 
label val hq_expect_quality_bin quality_new2
label var hq_expect_quality_bin "Good/excellent expected quality for high-quality solar lamp"

gen lq_expect_quality_bin=.
replace lq_expect_quality_bin=1 if lq_expected_quality==4 | lq_expected_quality==5 
replace lq_expect_quality_bin=0 if lq_expected_quality>=1 & lq_expected_quality<=3
label val lq_expect_quality_bin quality_new2
label var lq_expect_quality_bin "Good/excellent expected quality for low-quality solar lamp"

*difference in expectected quality for HQ and LQ lamp
gen diff_expected_quality=.
replace diff_expected_quality=(hq_expected_quality-lq_expected_quality) ///
		if hq_expected_quality!=. & lq_expected_quality!=. & ///
		hq_expected_quality!=9999 & lq_expected_quality!=9999
label var diff_expected_quality "Difference in expected quality: high-quality minus low-quality solar lamp"

gen diff_expect_quality_bin=(hq_expect_quality_bin-lq_expect_quality_bin) ///
	if lq_expect_quality_bin!=. & hq_expect_quality_bin!=.
label var diff_expect_quality_bin "Difference in good/excellent expected quality: high-quality minus low-quality solar lamp"

*-------------------------------------------------------------------------------

/*save dataset*/

save "$finaldata/QualitySignaling_Senegal_PrepData.dta", replace

*---------------------------------- The end -----------------------------------*
